/*
 * Copyright (C) 2012  Krzysztof Mazur <krzysiek@podlesie.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 */

#ifndef PU_PROTO_H_INCLUDED
#define PU_PROTO_H_INCLUDED

#include <compiler.h>
#include <asm_types.h>

#define PU_MAGIC	94

struct pu_header {
	u8 magic;		/* PU_MAGIC */
	u8 proto;		/* higher level protocol */
	be16 id;		/* identifier */
	be32 data_bytes;	/* data length */
} __packed;
#define PU_DATA_ERROR		0x80000000

#define PU_PROTO_CMD		1	/* simple command protocol */

#define PU_HEADER_LENGTH_MIN	1

#define PU_QWORD_SIZE		8

/*
 * we align payload to 8 bytes.
 */
#define pu_align_data(length)	(((length) + 7UL) & ~7UL)

#define PU_CMD_CLOSE		0

#define PU_CMD_STAT		1
struct pu_stat_resp {
	be32 first;
	be32 current;
	be32 igroup;			/* last important group */
	be32 generation;
	be32 samples_per_group;
	be32 sample_size;
} __packed;

#define PU_CMD_READ		2
struct pu_read {
	u32 sample;
} __packed;

#define	PU_EPERM		 1	/* Operation not permitted */
#define	PU_ENOENT		 2	/* No such file or directory */
#define	PU_EIO			 5	/* I/O error */
#define	PU_ENXIO		 6	/* No such device or address */
#define	PU_EAGAIN		11	/* Try again */
#define	PU_ENOMEM		12	/* Out of memory */
#define	PU_EACCES		13	/* Permission denied */
#define	PU_ENODEV		19	/* No such device */
#define	PU_EINVAL		22	/* Invalid argument */
#define	PU_ENOSYS		38	/* Function not implemented */
#define	PU_EPROTONOSUPPORT	93	/* Protocol not supported */
#define	PU_EUNKNOWN	0x7fffffff	/* Unknown error */

#endif
