/*
 * manhattan - pu-read.c
 *
 * Copyright (C) 2012  Krzysztof Mazur <krzysiek@podlesie.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <compiler.h>
#include <pu-lib.h>
#include <pu-buff.h>
#include <pu-proto.h>
#include <pu-proto-lib.h>
#include <dspcomm.h>

int pu_proto_read(void *priv, struct pu_buff *skb)
{
	struct pu_buff *n;
	struct pu_read *req;
	unsigned int sample;
	unsigned int sample_size;
	void *p;
	int ret;

	if (skb->len < sizeof(*req))
		return pu_proto_error(priv, skb, PU_EINVAL);

	req = (void *) skb->data;
	sample = be32_to_cpu(req->sample);

	sample_size = dsp_sample_size();
	n = pu_proto_alloc_skb(sample_size);
	p = pu_skb_put(n, sample_size);
	ret = copy_from_dsp(sample, 0, p, sample_size);
	if (ret) {
		pu_free_skb(n);
		return pu_proto_error_errno(priv, skb, -ret);
	}
	return pu_proto_xmit_resp(priv, n, skb);
}
